@@ -1,4 +1,4 @@
-#!/bin/bash -eu
+#!/bin/bash -eux
 # Copyright 2019 Google Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,10 +15,14 @@
 #
 ################################################################################
 
-mkdir build
-cd build
+mkdir oss_fuzz_build
+cd oss_fuzz_build
 # We disable libcbor's default sanitizers since we'll be configuring them ourselves via CFLAGS.
-cmake -D CMAKE_BUILD_TYPE=Debug -D CMAKE_INSTALL_PREFIX="$WORK" -D SANITIZE=OFF ..
+cmake -D CMAKE_BUILD_TYPE=Debug \
+      -D CMAKE_INSTALL_PREFIX="$WORK" \
+      -D SANITIZE=OFF \
+      -D CMAKE_INTERPROCEDURAL_OPTIMIZATION=OFF \
+      ..
 make "-j$(nproc)"
 make install
 
