@@ -6,7 +6,6 @@
  */
 
 // cbor_serialize_alloc
-#pragma clang diagnostic ignored "-Wdeprecated-declarations"
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 
 #include <math.h>
@@ -24,8 +23,8 @@
 
 unsigned char buffer[512];
 
-static void test_serialize_uint8_embed(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_int8();
+static void test_serialize_uint8_embed(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_int8();
   cbor_set_uint8(item, 0);
   assert_size_equal(1, cbor_serialize(item, buffer, 512));
   assert_memory_equal(buffer, (unsigned char[]){0x00}, 1);
@@ -33,8 +32,8 @@ static void test_serialize_uint8_embed(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_uint8(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_int8();
+static void test_serialize_uint8(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_int8();
   cbor_set_uint8(item, 42);
   assert_size_equal(2, cbor_serialize(item, buffer, 512));
   assert_memory_equal(buffer, ((unsigned char[]){0x18, 0x2a}), 2);
@@ -42,8 +41,8 @@ static void test_serialize_uint8(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_uint16(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_int16();
+static void test_serialize_uint16(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_int16();
   cbor_set_uint16(item, 1000);
   assert_size_equal(3, cbor_serialize(item, buffer, 512));
   assert_memory_equal(buffer, ((unsigned char[]){0x19, 0x03, 0xE8}), 3);
@@ -51,8 +50,8 @@ static void test_serialize_uint16(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_uint32(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_int32();
+static void test_serialize_uint32(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_int32();
   cbor_set_uint32(item, 1000000);
   assert_size_equal(5, cbor_serialize(item, buffer, 512));
   assert_memory_equal(buffer, ((unsigned char[]){0x1A, 0x00, 0x0F, 0x42, 0x40}),
@@ -61,8 +60,8 @@ static void test_serialize_uint32(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_uint64(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_int64();
+static void test_serialize_uint64(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_int64();
   cbor_set_uint64(item, 1000000000000);
   assert_size_equal(9, cbor_serialize(item, buffer, 512));
   assert_memory_equal(
@@ -73,8 +72,8 @@ static void test_serialize_uint64(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_negint8_embed(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_int8();
+static void test_serialize_negint8_embed(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_int8();
   cbor_set_uint8(item, 0);
   cbor_mark_negint(item);
   assert_size_equal(1, cbor_serialize(item, buffer, 512));
@@ -83,8 +82,8 @@ static void test_serialize_negint8_embed(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_negint8(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_int8();
+static void test_serialize_negint8(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_int8();
   cbor_set_uint8(item, 42);
   cbor_mark_negint(item);
   assert_size_equal(2, cbor_serialize(item, buffer, 512));
@@ -93,8 +92,8 @@ static void test_serialize_negint8(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_negint16(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_int16();
+static void test_serialize_negint16(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_int16();
   cbor_set_uint16(item, 1000);
   cbor_mark_negint(item);
   assert_size_equal(3, cbor_serialize(item, buffer, 512));
@@ -103,8 +102,8 @@ static void test_serialize_negint16(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_negint32(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_int32();
+static void test_serialize_negint32(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_int32();
   cbor_set_uint32(item, 1000000);
   cbor_mark_negint(item);
   assert_size_equal(5, cbor_serialize(item, buffer, 512));
@@ -114,8 +113,8 @@ static void test_serialize_negint32(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_negint64(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_int64();
+static void test_serialize_negint64(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_int64();
   cbor_set_uint64(item, 1000000000000);
   cbor_mark_negint(item);
   assert_size_equal(9, cbor_serialize(item, buffer, 512));
@@ -127,9 +126,9 @@ static void test_serialize_negint64(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_definite_bytestring(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_definite_bytestring();
-  unsigned char *data = malloc(256);
+static void test_serialize_definite_bytestring(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_definite_bytestring();
+  unsigned char* data = malloc(256);
   cbor_bytestring_set_handle(item, data, 256);
   memset(data, 0, 256); /* Prevent undefined behavior in comparison */
   assert_size_equal(256 + 3, cbor_serialize(item, buffer, 512));
@@ -139,11 +138,11 @@ static void test_serialize_definite_bytestring(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_indefinite_bytestring(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_indefinite_bytestring();
+static void test_serialize_indefinite_bytestring(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_indefinite_bytestring();
 
-  cbor_item_t *chunk = cbor_new_definite_bytestring();
-  unsigned char *data = malloc(256);
+  cbor_item_t* chunk = cbor_new_definite_bytestring();
+  unsigned char* data = malloc(256);
   memset(data, 0, 256); /* Prevent undefined behavior in comparison */
   cbor_bytestring_set_handle(chunk, data, 256);
 
@@ -159,11 +158,11 @@ static void test_serialize_indefinite_bytestring(void **_CBOR_UNUSED(_state)) {
 }
 
 static void test_serialize_bytestring_size_overflow(
-    void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_definite_bytestring();
+    void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_definite_bytestring();
 
   // Fake having a huge chunk of data
-  unsigned char *data = malloc(1);
+  unsigned char* data = malloc(1);
   cbor_bytestring_set_handle(item, data, SIZE_MAX);
 
   // Would require 1 + 8 + SIZE_MAX bytes, which overflows size_t
@@ -172,9 +171,9 @@ static void test_serialize_bytestring_size_overflow(
   cbor_decref(&item);
 }
 
-static void test_serialize_bytestring_no_space(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_definite_bytestring();
-  unsigned char *data = malloc(12);
+static void test_serialize_bytestring_no_space(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_definite_bytestring();
+  unsigned char* data = malloc(12);
   cbor_bytestring_set_handle(item, data, 12);
 
   assert_size_equal(cbor_serialize(item, buffer, 1), 0);
@@ -183,10 +182,10 @@ static void test_serialize_bytestring_no_space(void **_CBOR_UNUSED(_state)) {
 }
 
 static void test_serialize_indefinite_bytestring_no_space(
-    void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_indefinite_bytestring();
-  cbor_item_t *chunk = cbor_new_definite_bytestring();
-  unsigned char *data = malloc(256);
+    void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_indefinite_bytestring();
+  cbor_item_t* chunk = cbor_new_definite_bytestring();
+  unsigned char* data = malloc(256);
   cbor_bytestring_set_handle(chunk, data, 256);
   assert_true(cbor_bytestring_add_chunk(item, cbor_move(chunk)));
 
@@ -203,10 +202,10 @@ static void test_serialize_indefinite_bytestring_no_space(
   cbor_decref(&item);
 }
 
-static void test_serialize_definite_string(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_definite_string();
-  unsigned char *data = malloc(12);
-  strncpy((char *)data, "Hello world!", 12);
+static void test_serialize_definite_string(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_definite_string();
+  unsigned char* data = malloc(12);
+  strncpy((char*)data, "Hello world!", 12);
   cbor_string_set_handle(item, data, 12);
   assert_size_equal(1 + 12, cbor_serialize(item, buffer, 512));
   assert_memory_equal(
@@ -218,12 +217,40 @@ static void test_serialize_definite_string(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_indefinite_string(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_indefinite_string();
-  cbor_item_t *chunk = cbor_new_definite_string();
+static void test_serialize_definite_string_4b_header(
+    void** _state _CBOR_UNUSED) {
+#if SIZE_MAX > UINT16_MAX
+  cbor_item_t* item = cbor_new_definite_string();
+  const size_t size = (size_t)UINT16_MAX + 1;
+  unsigned char* data = malloc(size);
+  memset(data, 0, size);
+  cbor_string_set_handle(item, data, size);
+  assert_size_equal(cbor_serialized_size(item), 1 + 4 + size);
+  cbor_decref(&item);
+#endif
+}
 
-  unsigned char *data = malloc(12);
-  strncpy((char *)data, "Hello world!", 12);
+static void test_serialize_definite_string_8b_header(
+    void** _state _CBOR_UNUSED) {
+#if SIZE_MAX > UINT32_MAX
+  cbor_item_t* item = cbor_new_definite_string();
+  const size_t size = (size_t)UINT32_MAX + 1;
+  unsigned char* data = malloc(1);
+  data[0] = '\0';
+  cbor_string_set_handle(item, data, 1);
+  // Pretend that we have a big item to avoid the huge malloc
+  item->metadata.string_metadata.length = size;
+  assert_size_equal(cbor_serialized_size(item), 1 + 8 + size);
+  cbor_decref(&item);
+#endif
+}
+
+static void test_serialize_indefinite_string(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_indefinite_string();
+  cbor_item_t* chunk = cbor_new_definite_string();
+
+  unsigned char* data = malloc(12);
+  strncpy((char*)data, "Hello world!", 12);
   cbor_string_set_handle(chunk, data, 12);
 
   assert_true(cbor_string_add_chunk(item, cbor_move(chunk)));
@@ -239,9 +266,10 @@ static void test_serialize_indefinite_string(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_string_no_space(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_definite_string();
-  unsigned char *data = malloc(12);
+static void test_serialize_string_no_space(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_definite_string();
+  unsigned char* data = malloc(12);
+  memset(data, 0, 12);
   cbor_string_set_handle(item, data, 12);
 
   assert_size_equal(cbor_serialize(item, buffer, 1), 0);
@@ -250,10 +278,11 @@ static void test_serialize_string_no_space(void **_CBOR_UNUSED(_state)) {
 }
 
 static void test_serialize_indefinite_string_no_space(
-    void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_indefinite_string();
-  cbor_item_t *chunk = cbor_new_definite_string();
-  unsigned char *data = malloc(256);
+    void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_indefinite_string();
+  cbor_item_t* chunk = cbor_new_definite_string();
+  unsigned char* data = malloc(256);
+  memset(data, 0, 256);
   cbor_string_set_handle(chunk, data, 256);
   assert_true(cbor_string_add_chunk(item, cbor_move(chunk)));
 
@@ -270,10 +299,10 @@ static void test_serialize_indefinite_string_no_space(
   cbor_decref(&item);
 }
 
-static void test_serialize_definite_array(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_definite_array(2);
-  cbor_item_t *one = cbor_build_uint8(1);
-  cbor_item_t *two = cbor_build_uint8(2);
+static void test_serialize_definite_array(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_definite_array(2);
+  cbor_item_t* one = cbor_build_uint8(1);
+  cbor_item_t* two = cbor_build_uint8(2);
 
   assert_true(cbor_array_push(item, one));
   assert_true(cbor_array_set(item, 1, two));
@@ -287,9 +316,9 @@ static void test_serialize_definite_array(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&two);
 }
 
-static void test_serialize_array_no_space(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_indefinite_array();
-  cbor_item_t *one = cbor_build_uint8(1);
+static void test_serialize_array_no_space(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_indefinite_array();
+  cbor_item_t* one = cbor_build_uint8(1);
   assert_true(cbor_array_push(item, one));
   assert_size_equal(cbor_serialized_size(item), 3);
 
@@ -306,10 +335,10 @@ static void test_serialize_array_no_space(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&one);
 }
 
-static void test_serialize_indefinite_array(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_indefinite_array();
-  cbor_item_t *one = cbor_build_uint8(1);
-  cbor_item_t *two = cbor_build_uint8(2);
+static void test_serialize_indefinite_array(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_indefinite_array();
+  cbor_item_t* one = cbor_build_uint8(1);
+  cbor_item_t* two = cbor_build_uint8(2);
 
   assert_true(cbor_array_push(item, one));
   assert_true(cbor_array_push(item, two));
@@ -322,10 +351,10 @@ static void test_serialize_indefinite_array(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&two);
 }
 
-static void test_serialize_definite_map(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_definite_map(2);
-  cbor_item_t *one = cbor_build_uint8(1);
-  cbor_item_t *two = cbor_build_uint8(2);
+static void test_serialize_definite_map(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_definite_map(2);
+  cbor_item_t* one = cbor_build_uint8(1);
+  cbor_item_t* two = cbor_build_uint8(2);
 
   assert_true(cbor_map_add(item, (struct cbor_pair){.key = one, .value = two}));
   assert_true(cbor_map_add(item, (struct cbor_pair){.key = two, .value = one}));
@@ -339,10 +368,10 @@ static void test_serialize_definite_map(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&two);
 }
 
-static void test_serialize_indefinite_map(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_indefinite_map();
-  cbor_item_t *one = cbor_build_uint8(1);
-  cbor_item_t *two = cbor_build_uint8(2);
+static void test_serialize_indefinite_map(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_indefinite_map();
+  cbor_item_t* one = cbor_build_uint8(1);
+  cbor_item_t* two = cbor_build_uint8(2);
 
   assert_true(cbor_map_add(item, (struct cbor_pair){.key = one, .value = two}));
   assert_true(cbor_map_add(item, (struct cbor_pair){.key = two, .value = one}));
@@ -356,10 +385,10 @@ static void test_serialize_indefinite_map(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&two);
 }
 
-static void test_serialize_map_no_space(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_indefinite_map();
-  cbor_item_t *one = cbor_build_uint8(1);
-  cbor_item_t *two = cbor_build_uint8(2);
+static void test_serialize_map_no_space(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_indefinite_map();
+  cbor_item_t* one = cbor_build_uint8(1);
+  cbor_item_t* two = cbor_build_uint8(2);
   assert_true(cbor_map_add(item, (struct cbor_pair){.key = one, .value = two}));
   assert_size_equal(cbor_serialized_size(item), 4);
 
@@ -380,9 +409,9 @@ static void test_serialize_map_no_space(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&two);
 }
 
-static void test_serialize_tags(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_tag(21);
-  cbor_item_t *one = cbor_build_uint8(1);
+static void test_serialize_tags(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_tag(21);
+  cbor_item_t* one = cbor_build_uint8(1);
   cbor_tag_set_item(item, one);
 
   assert_size_equal(2, cbor_serialize(item, buffer, 512));
@@ -392,9 +421,9 @@ static void test_serialize_tags(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&one);
 }
 
-static void test_serialize_tags_no_space(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_tag(21);
-  cbor_item_t *one = cbor_build_uint8(1);
+static void test_serialize_tags_no_space(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_tag(21);
+  cbor_item_t* one = cbor_build_uint8(1);
   cbor_tag_set_item(item, one);
   assert_size_equal(cbor_serialized_size(item), 2);
 
@@ -408,8 +437,8 @@ static void test_serialize_tags_no_space(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&one);
 }
 
-static void test_serialize_half(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_float2();
+static void test_serialize_half(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_float2();
   cbor_set_float2(item, NAN);
 
   assert_size_equal(3, cbor_serialize(item, buffer, 512));
@@ -418,8 +447,8 @@ static void test_serialize_half(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_single(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_float4();
+static void test_serialize_single(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_float4();
   cbor_set_float4(item, 100000.0f);
 
   assert_size_equal(5, cbor_serialize(item, buffer, 512));
@@ -429,8 +458,8 @@ static void test_serialize_single(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_double(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_float8();
+static void test_serialize_double(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_float8();
   cbor_set_float8(item, -4.1);
 
   assert_size_equal(9, cbor_serialize(item, buffer, 512));
@@ -442,8 +471,8 @@ static void test_serialize_double(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_ctrl(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_undef();
+static void test_serialize_ctrl(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_undef();
 
   assert_size_equal(1, cbor_serialize(item, buffer, 512));
   assert_memory_equal(buffer, ((unsigned char[]){0xF7}), 1);
@@ -451,8 +480,8 @@ static void test_serialize_ctrl(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_serialize_long_ctrl(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_ctrl();
+static void test_serialize_long_ctrl(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_ctrl();
   cbor_set_ctrl(item, 254);
 
   assert_size_equal(2, cbor_serialize(item, buffer, 512));
@@ -461,13 +490,13 @@ static void test_serialize_long_ctrl(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_auto_serialize(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_definite_array(4);
+static void test_auto_serialize(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_definite_array(4);
   for (size_t i = 0; i < 4; i++) {
     assert_true(cbor_array_push(item, cbor_move(cbor_build_uint64(0))));
   }
 
-  unsigned char *output;
+  unsigned char* output;
   size_t output_size;
   assert_size_equal(cbor_serialize_alloc(item, &output, &output_size), 37);
   assert_size_equal(output_size, 37);
@@ -477,10 +506,10 @@ static void test_auto_serialize(void **_CBOR_UNUSED(_state)) {
   _cbor_free(output);
 }
 
-static void test_auto_serialize_no_size(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_build_uint8(1);
+static void test_auto_serialize_no_size(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_build_uint8(1);
 
-  unsigned char *output;
+  unsigned char* output;
   assert_size_equal(cbor_serialize_alloc(item, &output, NULL), 1);
   assert_memory_equal(output, ((unsigned char[]){0x01}), 1);
   assert_size_equal(cbor_serialized_size(item), 1);
@@ -488,16 +517,16 @@ static void test_auto_serialize_no_size(void **_CBOR_UNUSED(_state)) {
   _cbor_free(output);
 }
 
-static void test_auto_serialize_too_large(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_indefinite_string();
-  cbor_item_t *chunk = cbor_new_definite_string();
+static void test_auto_serialize_too_large(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_indefinite_string();
+  cbor_item_t* chunk = cbor_new_definite_string();
   assert_true(cbor_string_add_chunk(item, chunk));
 
   // Pretend the chunk is huge
   chunk->metadata.string_metadata.length = SIZE_MAX;
   assert_true(SIZE_MAX + 2 == 1);
   assert_size_equal(cbor_serialized_size(item), 0);
-  unsigned char *output;
+  unsigned char* output;
   size_t output_size;
   assert_size_equal(cbor_serialize_alloc(item, &output, &output_size), 0);
   assert_size_equal(output_size, 0);
@@ -508,11 +537,11 @@ static void test_auto_serialize_too_large(void **_CBOR_UNUSED(_state)) {
   cbor_decref(&item);
 }
 
-static void test_auto_serialize_alloc_fail(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_build_uint8(42);
+static void test_auto_serialize_alloc_fail(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_build_uint8(42);
 
   WITH_FAILING_MALLOC({
-    unsigned char *output;
+    unsigned char* output;
     size_t output_size;
     assert_size_equal(cbor_serialize_alloc(item, &output, &output_size), 0);
     assert_size_equal(output_size, 0);
@@ -523,10 +552,10 @@ static void test_auto_serialize_alloc_fail(void **_CBOR_UNUSED(_state)) {
 }
 
 static void test_auto_serialize_zero_len_bytestring(
-    void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_build_bytestring((cbor_data) "", 0);
+    void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_build_bytestring((cbor_data) "", 0);
 
-  unsigned char *output;
+  unsigned char* output;
   assert_size_equal(cbor_serialize_alloc(item, &output, NULL), 1);
   assert_memory_equal(output, ((unsigned char[]){0x40}), 1);
   assert_size_equal(cbor_serialized_size(item), 1);
@@ -534,10 +563,10 @@ static void test_auto_serialize_zero_len_bytestring(
   _cbor_free(output);
 }
 
-static void test_auto_serialize_zero_len_string(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_build_string("");
+static void test_auto_serialize_zero_len_string(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_build_string("");
 
-  unsigned char *output;
+  unsigned char* output;
   assert_size_equal(cbor_serialize_alloc(item, &output, NULL), 1);
   assert_memory_equal(output, ((unsigned char[]){0x60}), 1);
   assert_size_equal(cbor_serialized_size(item), 1);
@@ -546,13 +575,13 @@ static void test_auto_serialize_zero_len_string(void **_CBOR_UNUSED(_state)) {
 }
 
 static void test_auto_serialize_zero_len_bytestring_chunk(
-    void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_indefinite_bytestring();
+    void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_indefinite_bytestring();
 
   assert_true(cbor_bytestring_add_chunk(
       item, cbor_move(cbor_build_bytestring((cbor_data) "", 0))));
 
-  unsigned char *output;
+  unsigned char* output;
   assert_size_equal(cbor_serialize_alloc(item, &output, NULL), 3);
   assert_memory_equal(output, ((unsigned char[]){0x5f, 0x40, 0xff}), 3);
   assert_size_equal(cbor_serialized_size(item), 3);
@@ -561,12 +590,12 @@ static void test_auto_serialize_zero_len_bytestring_chunk(
 }
 
 static void test_auto_serialize_zero_len_string_chunk(
-    void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_indefinite_string();
+    void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_indefinite_string();
 
   assert_true(cbor_string_add_chunk(item, cbor_move(cbor_build_string(""))));
 
-  unsigned char *output;
+  unsigned char* output;
   assert_size_equal(cbor_serialize_alloc(item, &output, NULL), 3);
   assert_memory_equal(output, ((unsigned char[]){0x7f, 0x60, 0xff}), 3);
   assert_size_equal(cbor_serialized_size(item), 3);
@@ -574,10 +603,10 @@ static void test_auto_serialize_zero_len_string_chunk(
   _cbor_free(output);
 }
 
-static void test_auto_serialize_zero_len_array(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_definite_array(0);
+static void test_auto_serialize_zero_len_array(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_definite_array(0);
 
-  unsigned char *output;
+  unsigned char* output;
   assert_size_equal(cbor_serialize_alloc(item, &output, NULL), 1);
   assert_memory_equal(output, ((unsigned char[]){0x80}), 1);
   assert_size_equal(cbor_serialized_size(item), 1);
@@ -586,10 +615,10 @@ static void test_auto_serialize_zero_len_array(void **_CBOR_UNUSED(_state)) {
 }
 
 static void test_auto_serialize_zero_len_indef_array(
-    void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_indefinite_array();
+    void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_indefinite_array();
 
-  unsigned char *output;
+  unsigned char* output;
   assert_size_equal(cbor_serialize_alloc(item, &output, NULL), 2);
   assert_memory_equal(output, ((unsigned char[]){0x9f, 0xff}), 2);
   assert_size_equal(cbor_serialized_size(item), 2);
@@ -597,10 +626,10 @@ static void test_auto_serialize_zero_len_indef_array(
   _cbor_free(output);
 }
 
-static void test_auto_serialize_zero_len_map(void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_definite_map(0);
+static void test_auto_serialize_zero_len_map(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_definite_map(0);
 
-  unsigned char *output;
+  unsigned char* output;
   assert_size_equal(cbor_serialize_alloc(item, &output, NULL), 1);
   assert_memory_equal(output, ((unsigned char[]){0xa0}), 1);
   assert_size_equal(cbor_serialized_size(item), 1);
@@ -608,11 +637,10 @@ static void test_auto_serialize_zero_len_map(void **_CBOR_UNUSED(_state)) {
   _cbor_free(output);
 }
 
-static void test_auto_serialize_zero_len_indef_map(
-    void **_CBOR_UNUSED(_state)) {
-  cbor_item_t *item = cbor_new_indefinite_map();
+static void test_auto_serialize_zero_len_indef_map(void** _state _CBOR_UNUSED) {
+  cbor_item_t* item = cbor_new_indefinite_map();
 
-  unsigned char *output;
+  unsigned char* output;
   assert_size_equal(cbor_serialize_alloc(item, &output, NULL), 2);
   assert_memory_equal(output, ((unsigned char[]){0xbf, 0xff}), 2);
   assert_size_equal(cbor_serialized_size(item), 2);
@@ -638,6 +666,8 @@ int main(void) {
       cmocka_unit_test(test_serialize_bytestring_no_space),
       cmocka_unit_test(test_serialize_indefinite_bytestring_no_space),
       cmocka_unit_test(test_serialize_definite_string),
+      cmocka_unit_test(test_serialize_definite_string_4b_header),
+      cmocka_unit_test(test_serialize_definite_string_8b_header),
       cmocka_unit_test(test_serialize_indefinite_string),
       cmocka_unit_test(test_serialize_string_no_space),
       cmocka_unit_test(test_serialize_indefinite_string_no_space),
