@@ -1,9 +1,9 @@
 #include "assertions.h"
 #include "cbor.h"
 
-static size_t generate_overflow_data(unsigned char **overflow_data) {
+static size_t generate_overflow_data(unsigned char** overflow_data) {
   int i;
-  *overflow_data = (unsigned char *)malloc(CBOR_MAX_STACK_SIZE + 3);
+  *overflow_data = (unsigned char*)malloc(CBOR_MAX_STACK_SIZE + 3);
   for (i = 0; i < CBOR_MAX_STACK_SIZE + 1; i++) {
     (*overflow_data)[i] = 0xC2;  // tag of positive bignum
   }
@@ -12,8 +12,8 @@ static size_t generate_overflow_data(unsigned char **overflow_data) {
   return CBOR_MAX_STACK_SIZE + 3;
 }
 
-static void test_stack_over_limit(void **_CBOR_UNUSED(_state)) {
-  unsigned char *overflow_data;
+static void test_stack_over_limit(void** _state _CBOR_UNUSED) {
+  unsigned char* overflow_data;
   size_t overflow_data_len;
   struct cbor_load_result res;
   overflow_data_len = generate_overflow_data(&overflow_data);
